@@ -8,6 +8,11 @@ from sco_py.sco_osqp.variable import Variable
 
 
 DEFAULT_MAX_ITER = int(1e05)
+DEFAULT_SIGMA = 5e-10
+DEFAULT_RHO = 1e-01
+DEFAULT_ADAPTIVE_RHO = False
+DEFAULT_EPS_ABS = 1e-06
+DEFAULT_EPS_REL = 1e-09
 
 class OSQPVar(object):
     """
@@ -111,9 +116,12 @@ def optimize(
     osqp_quad_objs: List[OSQPQuadraticObj],
     osqp_lin_objs: List[OSQPLinearObj],
     osqp_lin_cnt_exprs: List[OSQPLinearConstraint],
-    eps_abs: float = 1e-06,
-    eps_rel: float = 1e-09,
+    eps_abs: float = DEFAULT_EPS_ABS,
+    eps_rel: float = DEFAULT_EPS_REL,
     max_iter: int = DEFAULT_MAX_ITER,
+    rho: float = DEFAULT_RHO,
+    adaptive_rho: bool = DEFAULT_ADAPTIVE_RHO,
+    sigma: float = DEFAULT_SIGMA,
     verbose: bool = False,
 ):
     """
@@ -190,8 +198,8 @@ def optimize(
         P=P_mat_sparse,
         q=q_vec,
         A=A_mat_sparse,
-        rho=0.1,
-        sigma=5e-10,
+        rho=rho,
+        sigma=sigma,
         l=l_vec,
         u=u_vec,
         eps_abs=eps_abs,
@@ -199,7 +207,7 @@ def optimize(
         delta=1e-07,
         # polish=True,
         polish=False,
-        adaptive_rho=False,
+        adaptive_rho=adaptive_rho,
         warm_start=True,
         verbose=False,
         max_iter=max_iter,
